@@ -96,7 +96,7 @@ flextable_to_rmd <- function(
     # with markdown package ----
     str <- html_value(x,
       ft.align = ft.align, bookdown = FALSE,
-      pandoc2 = FALSE, ft.shadow = FALSE
+      pandoc2 = pandoc2, ft.shadow = FALSE
     )
   } else if (is_xaringan) {
     # xaringan ----
@@ -178,8 +178,8 @@ html_value <- function(x, ft.align = opts_current$get("ft.align"), ft.shadow = o
   }
 
   caption_str <- caption_html_str(x, bookdown = bookdown)
-  if(pandoc2 && bookdown) {
-    # This is unfortunate but mandatory as bookdown need to scan captions...
+  if(pandoc2) {
+    # This is unfortunate but mandatory to let the caption be converted by pandoc...
     caption_str <- paste0("\n```\n", caption_str, "\n```{=html}\n")
   }
 
@@ -336,11 +336,12 @@ pptx_value <- function(x, ft.left = opts_current$get("ft.left"),
 #' Note also that a print method is used when flextable are used within
 #' R markdown documents. See [knit_print.flextable()].
 #' @param x flextable object
-#' @param preview preview type, one of c("html", "pptx", "docx", "log").
+#' @param preview preview type, one of c("html", "pptx", "docx", "pdf, "log").
 #' When `"log"` is used, a description of the flextable is printed.
-#' @param ... unused argument
+#' @param ... arguments for 'pdf_document' call when preview is "pdf".
 #' @family flextable print function
 #' @importFrom utils browseURL
+#' @importFrom rmarkdown render pdf_document
 #' @importFrom officer read_pptx add_slide read_docx
 print.flextable <- function(x, preview = "html", ...){
   if (!interactive() || "log" %in% preview ){
@@ -363,6 +364,12 @@ print.flextable <- function(x, preview = "html", ...){
     doc <- body_add_flextable(doc, value = x, align = "center")
     file_out <- print(doc, target = tempfile(fileext = ".docx"))
     browseURL(file_out)
+  } else if( preview == "pdf" ){
+    rmd <- tempfile(fileext = ".Rmd")
+    cat("```{r echo=FALSE}\nx\n```\n", file = rmd)
+    render(rmd, output_format = pdf_document(...), quiet = TRUE)
+    file_out <- gsub("\\.Rmd$", ".pdf", rmd)
+    browseURL(file_out)
   }
 
   invisible(NULL)
