@@ -94,3 +94,17 @@ format_double <- function(x, digits = 2){
 }
 
 
+# metric units -----
+cm_to_inches <- function(x) {
+  x / 2.54
+}
+mm_to_inches <- function(x) {
+  x / 254
+}
+convin <- function(unit, x) {
+  unit <- match.arg(unit, choices = c("in", "cm", "mm"), several.ok = FALSE)
+  if (!identical("in", unit)) {
+    x <- do.call(paste0(unit, "_to_inches"), list(x = x))
+  }
+  x
+}
